scale_node_pool

Function scale_node_pool 

pub async fn scale_node_pool(
    configuration: &Configuration,
    cluster_id: &str,
    pool_id: &str,
    pool_scale: PoolScale,
) -> Result<NodePoolView, Error<ScaleNodePoolError>>
Resizes a node pool to an absolute node count and returns the pool as Visor reports it after the change.