pub struct ConsoleSettingsGoogleAnalytics {
pub anonymize_users: Option<bool>,
pub tracking_id: Option<String>,
}Expand description
ConsoleSettingsGoogleAnalytics : GoogleAnalytics carries no tracking id and anonymizes users — this console reports no analytics.
Fields
anonymize_users: Option<bool>tracking_id: Option<String>Implementations
Sourceimpl ConsoleSettingsGoogleAnalytics
impl ConsoleSettingsGoogleAnalytics
Sourcepub fn new() -> ConsoleSettingsGoogleAnalytics
pub fn new() -> ConsoleSettingsGoogleAnalytics
GoogleAnalytics carries no tracking id and anonymizes users — this console reports no analytics.