pub struct ConsoleSettingsHelp {
pub binary_urls: Option<HashMap<String, String>>,
pub chat_text: Option<String>,
pub chat_url: Option<String>,
}Expand description
ConsoleSettingsHelp : Help carries no chat link and no binary download URLs.
Fields
binary_urls: Option<HashMap<String, String>>chat_text: Option<String>chat_url: Option<String>Implementations
Sourceimpl ConsoleSettingsHelp
impl ConsoleSettingsHelp
Sourcepub fn new() -> ConsoleSettingsHelp
pub fn new() -> ConsoleSettingsHelp
Help carries no chat link and no binary download URLs.