pub struct Consumer {
pub ack_floor: Option<Box<Sequences>>,
pub config: Option<Box<Durable>>,
pub created: Option<String>,
pub delivered: Option<Box<Sequences>>,
pub name: Option<String>,
pub num_ack_pending: Option<i32>,
pub num_pending: Option<i32>,
pub num_redelivered: Option<i32>,
pub num_waiting: Option<i32>,
pub stream_name: Option<String>,
}Fields
ack_floor: Option<Box<Sequences>>AckFloor is the highest contiguously acknowledged sequence pair.
config: Option<Box<Durable>>Config is the consumer’s configuration.
created: Option<String>Created is when the consumer was created.
delivered: Option<Box<Sequences>>Delivered is the highest delivered sequence pair.
name: Option<String>Name is the consumer name.
num_ack_pending: Option<i32>AckPending is the number of delivered, not yet acknowledged messages.
num_pending: Option<i32>Pending is the number of messages yet to be delivered.
num_redelivered: Option<i32>Redelivered is the number of messages currently being redelivered.
num_waiting: Option<i32>Waiting is the number of pull requests waiting for messages.
stream_name: Option<String>Stream is the stream this consumer reads.
Implementations