pub struct ControlDrain {
pub commands: Option<Vec<ControlCommandView>>,
pub cursor: Option<i32>,
}Fields
commands: Option<Vec<ControlCommandView>>Commands is the session’s control commands newer than the cursor, oldest first.
cursor: Option<i32>Cursor is the seq to send as after on the next poll — the highest seq in this page, or the cursor sent in when the page is empty.
Implementations
Sourceimpl ControlDrain
impl ControlDrain
pub fn new() -> ControlDrain