pub struct CreateVersionIn {
pub display_name: Option<String>,
pub id: Option<String>,
pub trigger: Option<Box<FlowTrigger>>,
}Fields
display_name: Option<String>DisplayName names the new version.
id: Option<String>ID is the flow to add a version to, from the path.
trigger: Option<Box<FlowTrigger>>Trigger is the root of the version’s step tree. Optional: a version with no trigger is created invalid, and cannot run until one is set.
Implementations
Sourceimpl CreateVersionIn
impl CreateVersionIn
pub fn new() -> CreateVersionIn