pub struct DataroomAddDocument {
pub document_id: Option<Option<Value>>,
pub id: Option<String>,
pub order_index: Option<Option<Value>>,
}Fields
document_id: Option<Option<Value>>id: Option<String>ID is the room to add to. It is the path segment: the URL is the addressing authority, and the org it is resolved in comes from the caller’s principal, so an id from another tenant is simply not found.
order_index: Option<Option<Value>>Implementations
Sourceimpl DataroomAddDocument
impl DataroomAddDocument
pub fn new() -> DataroomAddDocument