pub struct DeviceStartOut {
pub expires_at: Option<String>,
pub flow: Option<String>,
pub interval: Option<i32>,
pub user_code: Option<String>,
pub verify_url: Option<String>,
}Fields
expires_at: Option<String>ExpiresAt is when the flow dies, RFC 3339 UTC.
flow: Option<String>Flow is the id to poll with.
interval: Option<i32>Interval is the seconds to wait between polls.
user_code: Option<String>UserCode is the short code the user types at VerifyURL.
verify_url: Option<String>VerifyURL is the page the user opens to enter UserCode.
Implementations
Sourceimpl DeviceStartOut
impl DeviceStartOut
pub fn new() -> DeviceStartOut