pub struct DeviceView {
pub accounts: Option<Vec<LinkView>>,
pub active_sessions: Option<i32>,
pub host: Option<String>,
pub last_seen: Option<String>,
pub machine: Option<String>,
pub os: Option<String>,
}Fields
accounts: Option<Vec<LinkView>>Accounts is every account the caller has signed in on this machine.
active_sessions: Option<i32>ActiveSessions is how many agent sessions the caller currently has running on this machine; 0 where the agent plane is not mounted.
host: Option<String>Host is the machine’s hostname label, from its most-recently-seen account.
last_seen: Option<String>LastSeen is when any account on this machine last reported, RFC 3339 UTC.
machine: Option<String>Machine is the stable machine identifier.
os: Option<String>OS is the machine’s operating system label.
Implementations
Sourceimpl DeviceView
impl DeviceView
pub fn new() -> DeviceView