pub struct ImportCapTableOut {
pub formation: Option<Box<Formation>>,
pub rows: Option<i32>,
pub stakeholders_imported: Option<i32>,
}Fields
formation: Option<Box<Formation>>Formation is the org’s incorporation record, now marked cap-table-imported.
rows: Option<i32>Rows is how many rows were read from the sheet, header included.
stakeholders_imported: Option<i32>StakeholdersImported is how many stakeholders the cap table accepted.
Implementations
Sourceimpl ImportCapTableOut
impl ImportCapTableOut
pub fn new() -> ImportCapTableOut