pub struct InvoiceLine {
pub amount: Option<i32>,
pub description: Option<String>,
pub quantity: Option<i32>,
pub unit_price: Option<i32>,
}Fields
amount: Option<i32>Amount is the line total in whole cents (250000 is $2,500.00).
description: Option<String>Description is the human-readable line, e.g. "Advisory retainer — August".
quantity: Option<i32>Quantity is the number of units, when the line is metered. Optional.
unit_price: Option<i32>UnitPrice is the per-unit price in cents, when the line is metered. Optional.
Implementations
Sourceimpl InvoiceLine
impl InvoiceLine
pub fn new() -> InvoiceLine