pub struct State {
pub bytes: Option<i32>,
pub consumer_count: Option<i32>,
pub first_seq: Option<i32>,
pub first_ts: Option<String>,
pub last_seq: Option<i32>,
pub last_ts: Option<String>,
pub messages: Option<i32>,
pub num_deleted: Option<i32>,
pub num_subjects: Option<i32>,
}Fields
bytes: Option<i32>Bytes is the total stored size.
consumer_count: Option<i32>Consumers is the number of consumers attached to this stream.
first_seq: Option<i32>FirstSeq is the sequence of the first stored message.
first_ts: Option<String>FirstTS is the timestamp of the first stored message.
last_seq: Option<i32>LastSeq is the sequence of the last stored message.
last_ts: Option<String>LastTS is the timestamp of the last stored message.
messages: Option<i32>Messages is the number of messages currently stored.
num_deleted: Option<i32>Deleted is the number of deleted messages (sequence gaps).
num_subjects: Option<i32>Subjects is the number of distinct subjects stored.
Implementations