pub struct ValidatorList {
pub data: Option<Vec<SlotView>>,
pub network: Option<String>,
}Fields
data: Option<Vec<SlotView>>Data is one entry per slot this org has claimed.
network: Option<String>Network is the luxd network slug new nodes join on this deployment.
Implementations
Sourceimpl ValidatorList
impl ValidatorList
pub fn new() -> ValidatorList