post_code_ask

Function post_code_ask 

pub async fn post_code_ask(
    configuration: &Configuration,
    ask_post_in: AskPostIn,
) -> Result<AskAnswer, Error<PostCodeAskError>>
Is askGet with the question in the request BODY, for a question too long or too awkward to put in a URL. query and repo in the body take precedence over ?q= and ?repo=; either source works alone.